==> tine20-allinone_2019.12.5.tar.bz2: Crm/js/Crm-lang-bg-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Bulgarian (http://www.transifex.com/tine20/tine20/language/bg/)\nLanguage: bg\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Customer"
: "Клиент"

, "State"
: "Статус"

, "Role"
: ""

, "Source"
: "Код"

, "Start"
: "Старт"

, "Scheduled end"
: "Запланувана продължителност"

, "End"
: "Крайна дата"

, "Turnover"
: "Оборот"

, "Probability"
: "Вероятност"

, "Folder"
: "Папка"

, "Updated by"
: "Осъвременено от"

, "Updated Fields:"
: "Актуализирани полета:"

, "'%s' changed from '%s' to '%s'."
: ""

, "Tags"
: ""

, "Lead %s has been changed"
: "Предложението е %s променено"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: ""

, "Lead Data"
: "Данни за предложението"

, "Leadstate"
: "Статус на предложение"

, "Leadtype"
: "Тип на предложението"

, "Leadsource"
: "Източник на предложението"

, "End Scheduled"
: "Краен срок"

, "Contacts"
: "Контакти"

, "Address"
: "Адрес"

, "Telephone"
: "Телефон"

, "Email"
: "Имейл"

, "Tasks"
: "Задачи"

, "Due Date"
: "Краен срок"

, "Priority"
: "Приоритет"

, "Products"
: "Продукти"

, "low"
: "ниска"

, "normal"
: "нормална"

, "high"
: "висока"

, "urgent"
: "важност"

, "All leads I have read grants for"
: ""

, "Last modified by me"
: ""

, "All leads that I have last modified"
: ""

, "My leads"
: ""

, "All leads that I am responsible for"
: ""

, "Leads with overdue tasks"
: ""

, "All leads"
: ""

, "Default Lead List"
: ""

, "The default list for new leads"
: ""

, "Get Notification Emails"
: ""

, "The level of actions you want to be notified about."
: ""

, "Send Notifications Emails for own actions"
: ""

, "Get notifications emails for actions you did yourself"
: ""

, "Send Notifications Emails to responsible"
: ""

, "Get notifications emails for action to responsible"
: ""

, "Send Notifications Emails to customer"
: ""

, "Get notifications emails for action to customer"
: ""

, "Send Notifications Emails to partner"
: ""

, "Get notifications emails for action to partner"
: ""

, "Default Favorite"
: ""

, "The default favorite which is loaded on crm startup"
: ""

, "manage shared lead folders"
: "управление на споделените предложения"

, "Create new shared lead folders"
: "Създай нова папка за споделени предложения"

, "manage shared leads favorites"
: ""

, "Create or update shared leads favorites"
: ""

, "Contact"
: ""

, "CRM Role"
: ""

, "Lead, Leads"
: [
  ""
 ,""

]
, "lead list, lead lists"
: [
  ""
 ,""

]
, "lead lists"
: ""

, "Quick Search"
: ""

, "Lead name"
: "Име на предложение"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Estimated end"
: "Пресметната продължителност"

, "Resubmission Date"
: ""

, "X Lead"
: ""

, "Archived"
: ""

, "Partner"
: "Партньор/Съдружник"

, "Phone"
: "Телефон"

, "Mobile"
: ""

, "Fax"
: ""

, "E-Mail"
: ""

, "Web"
: ""

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Status"
: "Статус"

, "Change type to Customer"
: "Сменя типа контакт с Клиент"

, "Responsible"
: "Отговорник"

, "Change type to Responsible"
: "Сменя типа контакт с Отговорник"

, "Change type to Partner"
: "Сменя типа контакт с Партньор"

, "Change contact type"
: "Сменя контакт-тип"

, "Search for Contacts to add ..."
: "Търси да прибави контакти"

, "Name"
: "Име"

, "Data"
: ""

, "Cellphone"
: "Мобилен"

, "Add new {0}"
: ""

, "Unlink {0}"
: ""

, "Unlink selected {0}"
: ""

, "Edit {0}"
: ""

, "Edit selected {0}"
: ""

, "No Tasks to display"
: "Няма намерени задачи"

, "Summary"
: "Заключение"

, "Add a task..."
: "Добави задача"

, "Percent"
: "Процент"

, "Organizer"
: ""

, "Please choose the Lead to add the contacts to"
: ""

, "Please select the attenders' role"
: ""

, "Select Lead"
: ""

, "Select Role"
: ""

, "Adding {0} contacts to lead"
: ""

, "Probable Turnover"
: ""

, "Import leads"
: ""

, "You do not have the run right for the Tasks application or it is not activated."
: ""

, "You do not have the run right for the Sales application or it is not activated."
: ""

, "Enter lead name"
: ""

, "Expected turnover"
: "Очакван оборот"

, "Description"
: "Описание"

, "Enter description"
: "Напиши описание"

, "New Lead"
: ""

, "Product"
: "Продукт"

, "Price"
: "Цена"

, "Quantity"
: ""

, "Search for Products to add ..."
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Task"
: ""

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "отворен"

, "contacted"
: "осъществен контакт"

, "waiting for feedback"
: "чака отговор"

, "quote sent"
: "изпратена оферта"

, "accepted"
: "приет"

, "lost"
: "изгубен"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Crm Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification email on lead import"
: ""

, "Sends an email to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Lead"
: ""

, "lead list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Crm/js/Crm-lang-bg-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Bulgarian (http://www.transifex.com/tine20/tine20/language/bg/)\nLanguage: bg\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "All leads"
: ""

, "Default Lead List"
: ""

, "The default list for new leads"
: ""

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: ""

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Send Notifications e-mails to responsible"
: ""

, "Get notifications e-mails for action to responsible"
: ""

, "Send Notifications e-mails to customer"
: ""

, "Get notifications e-mails for action to customer"
: ""

, "Send Notifications e-mails to partner"
: ""

, "Get notifications e-mails for action to partner"
: ""

, "Default Favorite"
: ""

, "The default favorite which is loaded on crm startup"
: ""

, "New Lead"
: ""

, "Tags"
: ""

, "Lead name"
: "Име на предложение"

, "Responsible"
: "Отговорник"

, "Partner"
: "Партньор/Съдружник"

, "Customer"
: "Клиент"

, "Leadstate"
: "Статус на предложение"

, "Leadtype"
: "Тип на предложението"

, "Leadsource"
: "Източник на предложението"

, "Probability"
: "Вероятност"

, "Turnover"
: "Оборот"

, "Estimated end"
: "Пресметната продължителност"

, "Probable Turnover"
: ""

, "Resubmission Date"
: ""

, "Import leads"
: ""

, "Contact"
: ""

, "CRM Role"
: ""

, "Tasks"
: "Задачи"

, "No Tasks to display"
: "Няма намерени задачи"

, "Summary"
: "Заключение"

, "Add a task..."
: "Добави задача"

, "Due Date"
: "Краен срок"

, "Priority"
: "Приоритет"

, "Percent"
: "Процент"

, "Status"
: "Статус"

, "Organizer"
: ""

, "Add new {0}"
: ""

, "Unlink {0}"
: ""

, "Unlink selected {0}"
: ""

, "Edit {0}"
: ""

, "Edit selected {0}"
: ""

, "Please choose the Lead to add the contacts to"
: ""

, "Please select the attenders' role"
: ""

, "Lead, Leads"
: [
  ""
 ,""

]
, "Select Lead"
: ""

, "Role"
: ""

, "Select Role"
: ""

, "Adding {0} contacts to lead"
: ""

, "Phone"
: "Телефон"

, "Mobile"
: ""

, "Fax"
: ""

, "E-Mail"
: ""

, "Web"
: ""

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Start"
: "Старт"

, "Change type to Customer"
: "Сменя типа контакт с Клиент"

, "Change type to Responsible"
: "Сменя типа контакт с Отговорник"

, "Change type to Partner"
: "Сменя типа контакт с Партньор"

, "Change contact type"
: "Сменя контакт-тип"

, "Search for Contacts to add ..."
: "Търси да прибави контакти"

, "Name"
: "Име"

, "Address"
: "Адрес"

, "Data"
: ""

, "Cellphone"
: "Мобилен"

, "End"
: "Крайна дата"

, "You do not have the run right for the Tasks application or it is not activated."
: ""

, "Products"
: "Продукти"

, "You do not have the run right for the Sales application or it is not activated."
: ""

, "Enter lead name"
: ""

, "Expected turnover"
: "Очакван оборот"

, "Description"
: "Описание"

, "Enter description"
: "Напиши описание"

, "lead list, lead lists"
: [
  ""
 ,""

]
, "lead lists"
: ""

, "Quick Search"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "X Lead"
: ""

, "Archived"
: ""

, "Product"
: "Продукт"

, "Price"
: "Цена"

, "Quantity"
: ""

, "Search for Products to add ..."
: ""

, "All leads I have read grants for"
: ""

, "Last modified by me"
: ""

, "All leads that I have last modified"
: ""

, "My leads"
: ""

, "All leads that I am responsible for"
: ""

, "Leads with overdue tasks"
: ""

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "отворен"

, "contacted"
: "осъществен контакт"

, "waiting for feedback"
: "чака отговор"

, "quote sent"
: "изпратена оферта"

, "accepted"
: "приет"

, "lost"
: "изгубен"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: ""

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "State"
: "Статус"

, "Source"
: "Код"

, "Scheduled end"
: "Запланувана продължителност"

, "Folder"
: "Папка"

, "Updated by"
: "Осъвременено от"

, "Updated Fields:"
: "Актуализирани полета:"

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: "Предложението е %s променено"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: ""

, "Task"
: ""

, "Lead Data"
: "Данни за предложението"

, "End Scheduled"
: "Краен срок"

, "Contacts"
: "Контакти"

, "Telephone"
: "Телефон"

, "Email"
: "Имейл"

, "low"
: "ниска"

, "normal"
: "нормална"

, "high"
: "висока"

, "urgent"
: "важност"

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "manage shared lead folders"
: "управление на споделените предложения"

, "Create new shared lead folders"
: "Създай нова папка за споделени предложения"

, "manage shared leads favorites"
: ""

, "Create or update shared leads favorites"
: ""

, "Lead"
: ""

, "lead list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
